Learn R Programming

bootstrapFP (version 0.4.6)

is_wholenumber: Check if a number is integer

Description

Check if x is an integer number, differently from is.integer, which checks the type of the object x

Usage

is_wholenumber(x, tol = .Machine$double.eps^0.5)

Arguments

x

a scalar or a numeric vector

tol

a scalar, indicating the tolerance